macro_rules! define_report_macros {
{
# $title_1:tt
LEVEL
# $title_2:tt
$D:tt
$( [$($flag:tt)*] $level:ident )*
} => { ... };
}Expand description
Define a macro $level_report
The title line for the doc comment will be
$title_1 `LEVEL` $title_2
A standard body, containing a set of examples, will be provided.
You must pass a dollar sign for D, because there is no dollar escaping mechanism
for macro_rules macros in stable Rust (!)