HasKind

Trait HasKind 

pub trait HasKind {
    // Required method
    fn kind(&self) -> ErrorKind;
}
Errors that can be categorized as belonging to an ErrorKind

The most important implementation of this trait is arti_client::TorError; however, other internal errors throughout Arti also implement it.

Required Methods

fn kind(&self) -> ErrorKind

Return the kind of this error.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl HasKind for Infallible

Source

fn kind(&self) -> ErrorKind

Source

impl HasKind for SpawnError

Available on crate feature futures only.
Source

fn kind(&self) -> ErrorKind

Source

impl HasKind for Void

Source

fn kind(&self) -> ErrorKind

Implementors